@@ -7,10 +7,14 @@ from django.apps import AppConfig
 
 class EnrichAppConfig(AppConfig):
 
+    name="default"
+    namespace="default"
     filename = None
     enable = False
     multiple = False
     composition = False
+    entry = "index"
+    tags = ["store"]
 
     def get_usecase(self):
 
