@@ -354,6 +354,12 @@ class InMemoryQueryExecutorBase(Compute):
 
         return []
 
+    def get_registry(self):
+        """
+        Build a registry and return
+        """
+        return None
+
     def get_engine(self, spec):
         """
         Build and return an engine for a given specification.
@@ -409,6 +415,9 @@ class InMemoryQueryExecutorBase(Compute):
         # Will be used in other places..
         self.state = state
 
+        # Get the registry
+        self.registry = self.get_registry()
+
         # List of specification names
         targets = self.args["targets"]
 
@@ -445,6 +454,8 @@ class InMemoryQueryExecutorBase(Compute):
 
                 sql_template = spec["sql"]
 
+                files = []
+
                 paramsets = self.generate_paramsets(
                     spec, self.args["start_date"], self.args["end_date"]
                 )
@@ -532,12 +543,14 @@ class InMemoryQueryExecutorBase(Compute):
                             if "clean" in spec:
                                 callback = spec["clean"]["callback"]
                                 if callable(callback):
-                                    clean_msg, df1 = callback(
+                                    clean_msg, df1, clean_files = callback(
                                         self, segmentcol, segment, df1, spec
                                     )
                                     if len(clean_msg) > 0:
                                         msg += f"[{segment}] " + clean_msg + "\n"
+                                    files += clean_files
                         except Exception as e:
+                            #traceback.print_exc()
                             msg += str(e)
                             raise
 
@@ -548,13 +561,16 @@ class InMemoryQueryExecutorBase(Compute):
                                 # Separate storage handler..
                                 callback = spec["store"]["callback"]
                                 if callable(callback):
-                                    store_msg, store_dependencies = callback(
+                                    store_msg, store_dependencies, store_files = callback(
                                         self, segmentcol, segment, df1, spec
                                     )
                                     if len(store_msg) > 0:
                                         msg += f"[{segment}] " + store_msg + "\n"
                                     extra_dependencies += store_dependencies
+                                    files += store_files
+
                         except Exception as e:
+                            #traceback.print_exc()
                             msg += str(e)
                             raise
 
@@ -562,12 +578,13 @@ class InMemoryQueryExecutorBase(Compute):
                         try:
 
                             # Store in s3 etc.
-                            store_msg, store_dependencies = self.store(
+                            store_msg, store_dependencies, store_files  = self.store(
                                 segmentcol, segment, df1, spec
                             )
                             if len(store_msg) > 0:
                                 msg += f"[{segment}] " + store_msg
                             extra_dependencies += store_dependencies
+                            files += store_files
 
                             # update lineage
                             self.update_frame(
@@ -575,13 +592,22 @@ class InMemoryQueryExecutorBase(Compute):
                             )
 
                         except Exception as e:
+                            #traceback.print_exc()
                             msg += "[{}] Exception {}\n".format(segment, str(e))
 
                     logger.debug(
                         f"Completed {name} {params['start_date']}",
                         extra={"transform": self.name, "data": msg},
                     )
+
+                # Make note of it.
+                dataset = self.registry.find(spec['name'])
+                if ((dataset is not None) and (len(files) > 0)):
+                    metadata = { 'files': files}
+                    self.registry.access(dataset, metadata, nature='write')
+
             except:
+                #traceback.print_exc()
                 # Exception for each spec.
                 logger.exception(
                     f"Unable to run query: {name}",
