@@ -255,6 +255,7 @@ class MetricsBase(Compute):
         # Now no about constructucting the datasets
         datasets = {}
 
+        found = []
         sources = self.get_sources(profile)
         for source in sources:
 
@@ -263,6 +264,7 @@ class MetricsBase(Compute):
 
             if name not in required_sources:
                 continue
+            found.append(name)
 
             pipeline = source.get("pipeline", None)
             generate = source.get("generate", None)
@@ -316,6 +318,17 @@ class MetricsBase(Compute):
             else:
                 datasets[name] = df
 
+        missing = [s for s in required_sources if s not in found]
+        if len(missing) > 0: 
+            logger.error(
+                f"Missing {len(missing)} sources",
+                extra={
+                    "transform": self.name,
+                    "data": ", ".join(missing)
+                }
+            )
+            raise Exception("Missing sources")
+
         return datasets
 
     def get_spec_sources(self, spec, datasets):
