@@ -3,10 +3,15 @@ Standard transforms that can be directly included in
 any pipeline.
 """
 
-__all__ = ['FileOperations',
-           'JSONSink', 'JSONSource',
-           'PQExport', 'SQLExport',
-           'TableSink', 'TableSource']
+__all__ = [
+    "FileOperations",
+    "JSONSink",
+    "JSONSource",
+    "PQExport",
+    "SQLExport",
+    "TableSink",
+    "TableSource",
+]
 
 from .fileops import *
 from .jsonsink import *
