@@ -8,18 +8,14 @@ import sys
 import json
 from collections import defaultdict
 
-class ReconMixin(object):
 
+class ReconMixin(object):
     def check_all_columns_match(self, spec, segment, frames, params):
         """
         Check whether all columns match...
         """
 
-        status ={
-            "check": "Match columns",
-            "status": True,
-            "message": ""
-        }
+        status = {"check": "Match columns", "status": True, "message": ""}
 
         columns = set()
         for df in frames.values():
@@ -27,7 +23,7 @@ class ReconMixin(object):
 
         for name, df in frames.items():
             if columns != set(df.columns):
-                status['message'] += f"[{name}] Mismatch\n"
+                status["message"] += f"[{name}] Mismatch\n"
 
         return status
 
@@ -35,58 +31,53 @@ class ReconMixin(object):
         """
         Check whether shapes match...
         """
-        status ={
-            "check": "Match Shapes",
-            "status": True,
-            "message": "",
-            "details": ""
-        }
+        status = {"check": "Match Shapes", "status": True, "message": "", "details": ""}
 
         shapes = set()
         for df in frames.values():
             shapes.add(df.shape)
 
         if len(shapes) > 1:
-            status['status'] = False
-            status['message'] = f"Found {len(shapes)}. Expected 1"
+            status["status"] = False
+            status["message"] = f"Found {len(shapes)}. Expected 1"
             for name, df in frames.items():
-                status['details'] += f"[{name}] {df.shape}\n"
+                status["details"] += f"[{name}] {df.shape}\n"
 
         return status
 
     def default_checker(self, spec, data, checkspec, summary):
 
-        sources = spec['sources']
+        sources = spec["sources"]
 
         # Collect segments
         segments = set()
         for s in sources:
-            segments.update(list(data.get(s,{}).keys()))
+            segments.update(list(data.get(s, {}).keys()))
 
         # For each segment..
         for segment in segments:
 
             frames = {}
             status = {
-                'checker': "default_checker",
-                'check': 'Data Availability',
-                'status': True,
-                "message": ""
+                "checker": "default_checker",
+                "check": "Data Availability",
+                "status": True,
+                "message": "",
             }
             for s in sources:
                 if segment not in data.get(s, {}):
-                    status['status'] = False
-                    status['message'] += f"[{s}] Missing\n"
+                    status["status"] = False
+                    status["message"] += f"[{s}] Missing\n"
                     continue
                 df = data[s][segment]
                 if df is None:
-                    status['status'] = False
-                    status['message'] += f"[{s}] Null\n"
+                    status["status"] = False
+                    status["message"] += f"[{s}] Null\n"
                     continue
                 frames[s] = df
 
-            summary['segments'][segment].append(status)
-            if not status['status']:
+            summary["segments"][segment].append(status)
+            if not status["status"]:
                 continue
 
             def get_func(cls, name):
@@ -97,7 +88,9 @@ class ReconMixin(object):
 
                 # Check the caller module
                 callermod = sys.modules[cls.__module__]
-                func = getattr(callermod, name, getattr(callermod, "check_" + name, None))
+                func = getattr(
+                    callermod, name, getattr(callermod, "check_" + name, None)
+                )
                 if func is not None:
                     return func
                 if name in globals():
@@ -106,14 +99,14 @@ class ReconMixin(object):
 
                 raise Exception(f"Handler {name} could not be found")
 
-            for c in checkspec['checks']:
+            for c in checkspec["checks"]:
                 if isinstance(c, str):
                     handler = get_func(self, c)
                     params = {}
                 elif isinstance(c, dict):
-                    handler = c.get('handler', c.get('check'))
+                    handler = c.get("handler", c.get("check"))
                     handler = get_func(self, handler)
-                    params = c.get('params',{})
+                    params = c.get("params", {})
                 else:
                     raise Exception("Unknown check format")
 
@@ -122,9 +115,9 @@ class ReconMixin(object):
 
                 status = handler(spec, segment, frames, params)
                 if isinstance(status, dict):
-                    summary['segments'][segment].append(status)
+                    summary["segments"][segment].append(status)
                 elif isinstance(status, list):
-                    summary['segments'][segment].extend(status)
+                    summary["segments"][segment].extend(status)
                 else:
                     raise Exception(f"Invalid response from checker method {handler}")
 
@@ -139,10 +132,10 @@ class ReconMixin(object):
         specsummary = []
         for spec in specs:
 
-            name = spec['name']
+            name = spec["name"]
 
             # Get the checker specification.
-            checks = spec['checks']
+            checks = spec["checks"]
             if isinstance(checks, list) and isinstance(checks[0], str):
                 checks = [
                     {
@@ -151,10 +144,7 @@ class ReconMixin(object):
                 ]
 
             # Summary per-spec
-            summary = {
-                'spec': spec,
-                'segments': defaultdict(list)
-            }
+            summary = {"spec": spec, "segments": defaultdict(list)}
 
             # Go through each checker specification. There could be
             # potentially multiple strategies to check...
@@ -172,4 +162,3 @@ class ReconMixin(object):
             specsummary.append(summary)
 
         return specsummary
-
