@@ -11,7 +11,7 @@ import json
 import logging
 from datetime import datetime
 
-logger = logging.getLogger('app')
+logger = logging.getLogger("app")
 
 from .db import RedisBackend
 
@@ -22,6 +22,7 @@ class TransformBase(object):
     """
     Base for a realtime feature engineering transform
     """
+
     def __init__(self, *args, **kwargs):
         self.version = "v1.0"
         self.name = self.display = self.__class__.__name__
@@ -35,9 +36,9 @@ class TransformBase(object):
         self.args = args
 
         # Override the transform name..
-        self.enable  = self.args.get('enable', True)
-        self.display = self.args.get('display', self.display)
-        self.version = self.args.get('version', self.version)
+        self.enable = self.args.get("enable", True)
+        self.display = self.args.get("display", self.display)
+        self.version = self.args.get("version", self.version)
 
     def initialize(self):
         pass
@@ -54,6 +55,7 @@ class TransformBase(object):
         else:
             return {}
 
+
 ##############################################
 # DB Access Instances
 ##############################################
@@ -61,28 +63,31 @@ class RedisTransformBase(TransformBase):
     """
     Base class for Redis Read/Write Transforms
     """
+
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
     def initialize(self):
-        connparams = self.args.get('connection', {})
+        connparams = self.args.get("connection", {})
         self.backend = RedisBackend(config=connparams)
         self.backend.connect()
 
+
 class RedisReadTransform(RedisTransformBase):
     """
     Read from Redis
     """
+
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
     def process(self, state):
 
-        key = self.args.get('key',None)
+        key = self.args.get("key", None)
         if key is None:
             return state
 
-        streamrow = state.get('streamrow')
+        streamrow = state.get("streamrow")
 
         try:
             key = key % streamrow
@@ -90,28 +95,30 @@ class RedisReadTransform(RedisTransformBase):
             logger.exception("Cant compute the key")
             return state
 
-        name = self.args.get('name', 'dbrow')
+        name = self.args.get("name", "dbrow")
         dbrow = self.backend.get(key)
         state.put(name, dbrow)
 
         return state
 
+
 class RedisWriteTransform(RedisTransformBase):
     """
     Write to Redis
     """
+
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
     def process(self, state):
 
-        key = self.args.get('key',None)
+        key = self.args.get("key", None)
         if key is None:
             return state
 
-        streamrow = state.get('streamrow')
+        streamrow = state.get("streamrow")
 
-        name = self.args.get('name', 'dbrow')
+        name = self.args.get("name", "dbrow")
         dbrow = state.get(name)
 
         try:
@@ -126,7 +133,6 @@ class RedisWriteTransform(RedisTransformBase):
             logger.exception("Unable to post to backend")
             pass
 
-
         return state
 
 
@@ -134,7 +140,6 @@ class RedisWriteTransform(RedisTransformBase):
 # Metadata
 ##############################################
 class MetaStartTransform(TransformBase):
-
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
@@ -142,23 +147,20 @@ class MetaStartTransform(TransformBase):
 
         super().process(state)
 
-        streamrow = state.get('streamrow')
+        streamrow = state.get("streamrow")
 
         # Insert extra information
-        if not '_meta_' in streamrow:
-            streamrow['_meta_'] = {}
+        if not "_meta_" in streamrow:
+            streamrow["_meta_"] = {}
 
-        streamrow['_meta_'].update({
-            'start_ts': datetime.now().isoformat()
-        })
+        streamrow["_meta_"].update({"start_ts": datetime.now().isoformat()})
 
-        state.put('streamrow', streamrow)
+        state.put("streamrow", streamrow)
 
         return state
 
 
 class MetaEndTransform(TransformBase):
-
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
@@ -166,44 +168,39 @@ class MetaEndTransform(TransformBase):
 
         super().process(state)
 
-        streamrow = state.get('streamrow')
+        streamrow = state.get("streamrow")
 
         extra = self.get_pipeline_extra()
-        extra.update({
-            'end_ts': datetime.now().isoformat()
-        })
+        extra.update({"end_ts": datetime.now().isoformat()})
 
-        if not '_meta_' in streamrow:
-            streamrow['_meta_'] = {}
+        if not "_meta_" in streamrow:
+            streamrow["_meta_"] = {}
 
-        streamrow['_meta_'].update(extra)
+        streamrow["_meta_"].update(extra)
 
         return state
 
-class LoggerTransform(TransformBase):
 
+class LoggerTransform(TransformBase):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
     def initialize(self):
-        name = self.args.get('name', __name__)
+        name = self.args.get("name", __name__)
         self.logger = logging.getLogger(name)
 
     def process(self, state):
 
         super().process(state)
 
-        streamrow = state.get('streamrow')
-        dbrow = state.get('dbrow',{})
+        streamrow = state.get("streamrow")
+        dbrow = state.get("dbrow", {})
 
         # Clean up the record before posting
-        streamrow.pop('message',"")
-        streamrow['_meta_'].pop('message',"")
-        extra = self.args.get('extra',{})
-        extra['data'] = {
-            'streamrow': streamrow,
-            'dbrow': dbrow
-        }
+        streamrow.pop("message", "")
+        streamrow["_meta_"].pop("message", "")
+        extra = self.args.get("extra", {})
+        extra["data"] = {"streamrow": streamrow, "dbrow": dbrow}
 
         self.logger.debug("Message", extra=extra)
 
