@@ -15,11 +15,11 @@ class Log4j(object):
 
     def __init__(self, spark):
         # get spark app details with which to prefix all messages
-        app_id = spark.sparkContext.getConf().get('spark.app.id')
-        app_name = spark.sparkContext.getConf().get('spark.app.name')
+        app_id = spark.sparkContext.getConf().get("spark.app.id")
+        app_name = spark.sparkContext.getConf().get("spark.app.name")
 
         log4j = spark._jvm.org.apache.log4j
-        message_prefix = '<' + app_name + ' ' + app_id + '>'
+        message_prefix = "<" + app_name + " " + app_id + ">"
         self.logger = log4j.LogManager.getLogger(message_prefix)
 
     def error(self, message):
